@@ -106,6 +106,9 @@ config.N2N_OFFER_INTERNAL = false;
 
 config.AMZ_DATE_MAX_TIME_SKEW_MILLIS = 15 * 60 * 1000;
 config.ENDPOINT_MONITOR_INTERVAL = 10 * 60 * 1000; // 10min
+// Keep connection on long requests
+config.S3_KEEP_ALIVE_WHITESPACE_INTERVAL = 15 * 1000;
+config.S3_MD_SIZE_LIMIT = 2 * 1024;
 
 ///////////////
 // MD CONFIG //
@@ -511,6 +514,19 @@ config.DB_TYPE = process.env.DB_TYPE || 'mongodb';
 ////////////////////////////////
 config.NAMESPACE_MONITOR_DELAY = 3 * 60 * 1000;
 
+
+////////////////////////////////
+//      BUCKET REPLICATOR     //
+////////////////////////////////
+
+config.BUCKET_REPLICATOR_DELAY = 5 * 60 * 1000;
+config.BUCKET_REPLICATOR_LIST_LIMIT = 1000;
+config.BUCKET_REPLICATION_MAX_RULES = 1000;
+config.BUCKET_REPLICATION_MAX_DST_BUCKETS = 100;
+config.REPLICATION_SEMAPHORE_CAP = 5000;
+config.REPLICATION_SEMAPHORE_TIMEOUT = 300 * 1000;
+config.REPLICATION_ENABLED = true;
+
 ///////////////////////
 // NAMESPACE CACHING //
 ///////////////////////
@@ -550,6 +566,21 @@ config.NSFS_DIR_CACHE_MAX_DIR_SIZE = 64 * 1024 * 1024;
 config.NSFS_DIR_CACHE_MIN_DIR_SIZE = 64;
 config.NSFS_DIR_CACHE_MAX_TOTAL_SIZE = 24 * config.NSFS_DIR_CACHE_MAX_DIR_SIZE;
 
+config.BASE_MODE_FILE = 0o666;
+config.BASE_MODE_DIR = 0o777;
+// umask that will be used for creation of directories and files with no permissions for 'others'
+config.NSFS_UMASK = 0o007;
+
+// The threshold in milliseconds for prompting a warning
+config.NSFS_WARN_THRESHOLD_MS = 100;
+
+config.NSFS_CALCULATE_MD5 = true;
+config.NSFS_TRIGGER_FSYNC = true;
+config.NSFS_REMOVE_PARTS_ON_COMPLETE = true;
+
+config.NSFS_BUF_POOL_WARNING_TIMEOUT = 2 * 60 * 1000;
+config.NSFS_SEM_WARNING_TIMEOUT = 10 * 60 * 1000;
+
 /////////////////////
 //                 //
 //    OVERRIDES    //
@@ -602,7 +633,7 @@ function load_config_env_overrides() {
                     config[conf_name] = true;
                 } else if (val === 'false') {
                     console.log(`Overriding config.js from ENV with ${conf_name}=false (bool)`);
-                    config[conf_name] = true;
+                    config[conf_name] = false;
                 } else {
                     throw new Error(`${val} should be true|false`);
                 }
