@@ -29,7 +29,7 @@ const dbg_level =
     (process.env.SUPPRESS_LOGS && -5) ||
     (argv.verbose && 5) ||
     0;
-dbg.set_level(dbg_level, 'core');
+dbg.set_module_level(dbg_level, 'core');
 
 const P = require('../../util/promise');
 const ObjectIO = require('../../sdk/object_io');
@@ -181,9 +181,9 @@ function setup(options = {}) {
         const http_port = http_net_address.port;
         const https_port = https_net_address.port;
 
-        base_address = `wss://127.0.0.1:${https_port}`;
-        http_address = `http://127.0.0.1:${http_port}`;
-        https_address = `https://127.0.0.1:${https_port}`;
+        base_address = `wss://localhost:${https_port}`;
+        http_address = `http://localhost:${http_port}`;
+        https_address = `https://localhost:${https_port}`;
 
         // update the nodes_monitor n2n_rpc to find the base_address correctly for signals
         await node_server.start_monitor();
@@ -476,7 +476,7 @@ function set_pool_as_default_resource(pool_name) {
         update: {
             accounts: _.map(system_store.data.accounts, account => ({
                 _id: account._id,
-                default_pool: pool_id,
+                default_resource: pool_id,
             }))
         }
     });
